@@ -31,12 +31,14 @@
 #include <libedataserver/e-account.h>
 #include <libedataserver/e-account-list.h>
 #include <libebook/e-book.h>
-#include <camel-ews-utils.h>
+
+#include "camel/camel-ews-store-summary.h"
+#include "camel/camel-ews-utils.h"
+
+#include "utils/ews-esource-utils.h"
 
 #include "exchange-ews-account-listener.h"
 #include "exchange-ews-account-setup.h"
-#include "camel-ews-store-summary.h"
-#include "ews-esource-utils.h"
 
 #define d(x)
 
@@ -261,7 +263,6 @@ add_gal_esource (CamelURL *url)
 
 	e_source_set_property (source, "auth", "plain/password");
 	e_source_set_property (source, "completion", "true");
-	e_source_set_property (source, "ews-auth-type", camel_url_get_param (url, "auth"));
 
 	/* add the source to group and sync */
 	group = ews_esource_utils_ensure_group (source_list, url);
