@@ -23,17 +23,20 @@
 #include "config.h"
 #endif
 
+#include "exchange-ews-account-out-of-office.h"
+
 #include <string.h>
 #include <unistd.h>
 #include <glib/gi18n-lib.h>
 
 #include <gtk/gtk.h>
-#include <e-ews-connection.h>
 #include <misc/e-dateedit.h>
-#include <camel-ews-settings.h>
 #include <e-util/e-dialog-utils.h>
 #include <libedataserverui/e-passwords.h>
-#include <exchange-ews-account-out-of-office.h>
+
+#include "server/e-ews-connection.h"
+
+#include "utils/camel-ews-settings.h"
 
 #define d(x) x
 
@@ -164,7 +167,7 @@ toggled_state_cb (GtkToggleButton *button,
 
 static void
 toggled_set_date_cb (GtkToggleButton *button,
-		     gpointer data)
+                     gpointer data)
 {
 	gboolean current_state;
 
@@ -370,10 +373,9 @@ set_oof_settings_to_frame (GtkWidget *oof_frame)
 	/*Check box for setting date*/
 	set_range = gtk_check_button_new_with_mnemonic (_("_Send only during this time period"));
 	oof_data->range_wt = set_range;
-	gtk_toggle_button_set_active ((GtkToggleButton*) set_range, oof_data->set_range);
+	gtk_toggle_button_set_active ((GtkToggleButton *) set_range, oof_data->set_range);
 	g_signal_connect ((GtkToggleButton*) set_range, "toggled", G_CALLBACK (toggled_set_date_cb), NULL);
 
-
 	/*Selectable Dates*/
 	from_date = e_date_edit_new ();
 	to_date = e_date_edit_new ();
@@ -537,9 +539,9 @@ set_oof_data_from_settings (EMConfigTargetSettings *target,
 
 	cancellable = g_cancellable_new ();
 
-	e_ews_connection_get_oof_settings_start (cnc, EWS_PRIORITY_MEDIUM,
-						 get_oof_settings_cb, cancellable,
-						 oof_frame);
+	e_ews_connection_get_oof_settings (
+		cnc, EWS_PRIORITY_MEDIUM, cancellable,
+		get_oof_settings_cb, oof_frame);
 }
 
 static OOFSettings *
@@ -591,9 +593,9 @@ ews_set_oof_settings (EMConfigTargetSettings *target)
 
 	oof_settings = get_settings_from_data ();
 
-	e_ews_connection_set_oof_settings (cnc, EWS_PRIORITY_MEDIUM,
-					   oof_settings, cancellable,
-					   &error);
+	e_ews_connection_set_oof_settings_sync (
+		cnc, EWS_PRIORITY_MEDIUM,
+		oof_settings, cancellable, &error);
 
 	if (error) {
 		g_warning ("Error While setting out of office: %s\n", error->message);
