@@ -27,24 +27,31 @@
 #include <glib/gi18n-lib.h>
 
 #include <gtk/gtk.h>
+
 #include <libedataserver/e-xml-hash-utils.h>
 #include <libedataserverui/e-passwords.h>
 #include <libedataserver/e-account.h>
 #include <libedataserver/eds-version.h>
+
 #include <e-util/e-dialog-utils.h>
-#include "mail/em-config.h"
-#include "exchange-ews-account-setup.h"
+#include <mail/em-config.h>
 #include <addressbook/gui/widgets/eab-config.h>
 #include <calendar/gui/e-cal-config.h>
-#include <exchange-ews-account-out-of-office.h>
 
 #include <camel/camel.h>
-#include <camel-ews-folder.h>
-#include <camel-ews-settings.h>
-#include <e-ews-connection.h>
-#include <camel-ews-utils.h>
 #include <shell/e-shell.h>
 
+#include "camel/camel-ews-folder.h"
+#include "camel/camel-ews-utils.h"
+
+#include "server/e-ews-connection.h"
+
+#include "utils/camel-ews-settings.h"
+
+#include "exchange-ews-account-out-of-office.h"
+#include "exchange-ews-account-setup.h"
+#include "exchange-ews-change-password.h"
+
 #define d(x) x
 
 #if GTK_CHECK_VERSION(2,24,0)
@@ -535,7 +542,8 @@ fetch_button_clicked_cb (GtkButton *button,
 	/* pass user name while creating connection  to fetch oals */
 	cnc = e_ews_connection_new (oab_url, user, password, NULL, NULL, NULL);
 	cbdata->cancellable = cancellable;
-	e_ews_connection_get_oal_list_start (cnc, ews_oal_list_ready, cancellable, cbdata);
+	e_ews_connection_get_oal_list (
+		cnc, cancellable, ews_oal_list_ready, cbdata);
 
 	g_free (password);
 }
@@ -737,7 +745,7 @@ org_gnome_ews_settings (EPlugin *epl,
 {
 	EMConfigTargetSettings *target_account;
 	GtkVBox *vbox_settings;
-	GtkWidget *oof;
+	GtkWidget *oof, *chgpwd;
 
 	target_account = (EMConfigTargetSettings *) data->config->target;
 
@@ -760,6 +768,10 @@ org_gnome_ews_settings (EPlugin *epl,
 	oof = ews_get_outo_office_widget (target_account);
 	gtk_box_pack_start (GTK_BOX (vbox_settings), oof, FALSE, FALSE, 0);
 
+	/*Get Change Password widget*/
+	chgpwd = ews_get_change_pwd_widget (target_account);
+	gtk_box_pack_start (GTK_BOX (vbox_settings), chgpwd, FALSE, FALSE, 0);
+
 	gtk_widget_show_all (GTK_WIDGET (vbox_settings));
 	gtk_notebook_insert_page (GTK_NOTEBOOK (data->parent), GTK_WIDGET (vbox_settings), gtk_label_new(_("EWS Settings")), 4);
 	return GTK_WIDGET (vbox_settings);
