@@ -48,12 +48,13 @@
 #include "e-book-backend-sqlitedb.h"
 #include "lzx/ews-oal-decompress.h"
 #include "ews-oab-decoder.h"
-#include "e-ews-item-change.h"
 
-#include "e-ews-message.h"
-#include "e-ews-connection.h"
-#include "e-ews-item.h"
-#include <e-ews-query-to-restriction.h>
+#include "server/e-ews-item-change.h"
+#include "server/e-ews-message.h"
+#include "server/e-ews-connection.h"
+#include "server/e-ews-item.h"
+
+#include "utils/e-ews-query-to-restriction.h"
 
 #define d(x) x
 
@@ -86,7 +87,6 @@ struct _EBookBackendEwsPrivate {
 	gboolean marked_for_offline;
 	gboolean cache_ready;
 	gboolean is_gal;
-	gboolean is_online;
 
 	GHashTable *ops;
 
@@ -955,7 +955,7 @@ e_book_backend_ews_create_contacts (EBookBackend *backend,
 	ebews = E_BOOK_BACKEND_EWS (backend);
 	priv = ebews->priv;
 
-	if (!priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		if (!priv->is_writable) {
 			e_data_book_respond_create_contacts (book, opid, EDB_ERROR (PERMISSION_DENIED), NULL);
 			return;
@@ -990,15 +990,16 @@ e_book_backend_ews_create_contacts (EBookBackend *backend,
 	create_contact->contact = g_object_ref (contact);
 
 	/* pass new contact component data to the exchange server and expect response in the callback */
-	e_ews_connection_create_items_start (priv->cnc,
-					     EWS_PRIORITY_MEDIUM, NULL,
-					     NULL,
-					     priv->folder_id,
-					     convert_contact_to_xml,
-					     contact,
-					     ews_create_contact_cb,
-					     cancellable,
-					     create_contact);
+	e_ews_connection_create_items (
+		priv->cnc,
+		EWS_PRIORITY_MEDIUM, NULL,
+		NULL,
+		priv->folder_id,
+		convert_contact_to_xml,
+		contact,
+		cancellable,
+		ews_create_contact_cb,
+		create_contact);
 }
 
 typedef struct {
@@ -1057,7 +1058,7 @@ e_book_backend_ews_remove_contacts (EBookBackend *backend,
 
 	priv = ebews->priv;
 
-	if (!priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		if (!priv->is_writable) {
 			e_data_book_respond_remove_contacts (book, opid, EDB_ERROR (PERMISSION_DENIED), NULL);
 			return;
@@ -1087,10 +1088,12 @@ e_book_backend_ews_remove_contacts (EBookBackend *backend,
 	remove_contact->opid = opid;
 	remove_contact->sl_ids = copy;
 
-	e_ews_connection_delete_items_start (priv->cnc, EWS_PRIORITY_MEDIUM, (GSList *) id_list,
-					     EWS_HARD_DELETE, 0 , FALSE,
-					     ews_book_remove_contact_cb, cancellable,
-					     remove_contact);
+	e_ews_connection_delete_items (
+		priv->cnc, EWS_PRIORITY_MEDIUM, (GSList *) id_list,
+		EWS_HARD_DELETE, 0 , FALSE,
+		cancellable,
+		ews_book_remove_contact_cb,
+		remove_contact);
 }
 
 typedef struct {
@@ -1226,7 +1229,7 @@ e_book_backend_ews_modify_contacts (EBookBackend *backend,
 	ebews = E_BOOK_BACKEND_EWS (backend);
 	priv = ebews->priv;
 
-	if (!priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		if (!priv->is_writable) {
 			e_data_book_respond_modify_contacts (book, opid, EDB_ERROR (PERMISSION_DENIED), NULL);
 			return;
@@ -1275,12 +1278,14 @@ e_book_backend_ews_modify_contacts (EBookBackend *backend,
 	modify_contact->opid = opid;
 	modify_contact->old_contact = g_object_ref (old_contact);
 	modify_contact->new_contact = g_object_ref (contact);
-	e_ews_connection_update_items_start (priv->cnc, EWS_PRIORITY_MEDIUM,
-						"AlwaysOverwrite", "SendAndSaveCopy",
-						"SendToAllAndSaveCopy", priv->folder_id,
-						convert_contact_to_updatexml, modify_contact,
-						ews_modify_contact_cb, cancellable,
-						modify_contact);
+	e_ews_connection_update_items (
+		priv->cnc, EWS_PRIORITY_MEDIUM,
+		"AlwaysOverwrite", "SendAndSaveCopy",
+		"SendToAllAndSaveCopy", priv->folder_id,
+		convert_contact_to_updatexml, modify_contact,
+		cancellable,
+		ews_modify_contact_cb,
+		modify_contact);
 }
 
 static void
@@ -1294,7 +1299,7 @@ e_book_backend_ews_get_contact (EBookBackend *backend,
 
 	ebews =  E_BOOK_BACKEND_EWS (backend);
 
-	if (!ebews->priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		e_data_book_respond_get_contact (book, opid, EDB_ERROR (CONTACT_NOT_FOUND), "");
 		return;
 	}
@@ -1322,7 +1327,7 @@ e_book_backend_ews_get_contact_list (EBookBackend *backend,
 	ebews = E_BOOK_BACKEND_EWS (backend);
 	priv = ebews->priv;
 
-	if (!priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		if (e_book_backend_sqlitedb_get_is_populated (priv->ebsdb, priv->folder_id, NULL)) {
 			list = e_book_backend_sqlitedb_search (priv->ebsdb, priv->folder_id, query, NULL, NULL, NULL, &error);
 			l = list;
@@ -1378,12 +1383,13 @@ e_book_backend_ews_get_contact_list (EBookBackend *backend,
 		fid->id = g_strdup (priv->folder_id);
 		fid->is_distinguished_id = FALSE;
 
-		e_ews_connection_find_folder_items (priv->cnc, EWS_PRIORITY_MEDIUM,
-							fid, "IdOnly", NULL, NULL, query,
-							EWS_FOLDER_TYPE_CONTACTS,
-							&includes_last_item,
-							&items, (EwsConvertQueryCallback) (e_ews_query_to_restriction),
-							cancellable, &error);
+		e_ews_connection_find_folder_items_sync (
+			priv->cnc, EWS_PRIORITY_MEDIUM,
+			fid, "IdOnly", NULL, NULL, query,
+			EWS_FOLDER_TYPE_CONTACTS,
+			&includes_last_item,
+			&items, (EwsConvertQueryCallback) (e_ews_query_to_restriction),
+			cancellable, &error);
 
 		/*we have got Id for items lets fetch them using getitem operation*/
 		ebews_fetch_items (ebews, items, FALSE, &vcard_list, cancellable, &error);
@@ -1646,7 +1652,8 @@ ews_download_full_gal (EBookBackendEws *cbews,
 	comp_cache_file = g_build_filename (cache_dir, full->filename, NULL);
 
 	oab_cnc = e_ews_connection_new (full_url, priv->username, priv->password, NULL, NULL, NULL);
-	if (!e_ews_connection_download_oal_file (oab_cnc, comp_cache_file, NULL, NULL, cancellable, error))
+	if (!e_ews_connection_download_oal_file_sync (
+		oab_cnc, comp_cache_file, NULL, NULL, cancellable, error))
 		goto exit;
 
 	cache_file = g_strdup_printf ("%s-%d.oab", priv->folder_name, full->seq);
@@ -1792,7 +1799,9 @@ ebews_start_gal_sync (gpointer data)
 
 	d(printf ("Ewsgal: Fetching oal full details file \n");)
 
-	if (!e_ews_connection_get_oal_detail (oab_cnc, priv->folder_id, "Full", &full_l, priv->cancellable, &error)) {
+	if (!e_ews_connection_get_oal_detail_sync (
+		oab_cnc, priv->folder_id, "Full", &full_l,
+		priv->cancellable, &error)) {
 		ret = FALSE;
 		goto exit;
 	}
@@ -2092,7 +2101,7 @@ ebews_fetch_items (EBookBackendEws *ebews,
                    GSList *items,
                    gboolean store_to_cache,
                    GSList **vcards,
-		   GCancellable *cancellable,
+                   GCancellable *cancellable,
                    GError **error)
 {
 	EBookBackendEwsPrivate *priv;
@@ -2122,11 +2131,11 @@ ebews_fetch_items (EBookBackendEws *ebews,
 
 	/* TODO fetch attachments */
 	if (contact_item_ids)
-		e_ews_connection_get_items
-			(cnc, EWS_PRIORITY_MEDIUM,
-			 contact_item_ids, "Default", CONTACT_ITEM_PROPS,
-			 FALSE, NULL, &new_items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			cnc, EWS_PRIORITY_MEDIUM,
+			contact_item_ids, "Default", CONTACT_ITEM_PROPS,
+			FALSE, NULL, &new_items, NULL, NULL,
+			cancellable, error);
 	if (*error)
 		goto cleanup;
 
@@ -2140,11 +2149,11 @@ ebews_fetch_items (EBookBackendEws *ebews,
 
 	/* Get the display names of the distribution lists */
 	if (dl_ids)
-		e_ews_connection_get_items
-			(cnc, EWS_PRIORITY_MEDIUM,
-			 dl_ids, "Default", NULL,
-			 FALSE, NULL, &new_items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			cnc, EWS_PRIORITY_MEDIUM,
+			dl_ids, "Default", NULL,
+			FALSE, NULL, &new_items, NULL, NULL,
+			cancellable, error);
 	if (*error)
 		goto cleanup;
 
@@ -2168,7 +2177,9 @@ ebews_fetch_items (EBookBackendEws *ebews,
 			goto cleanup;
 
 		d_name = e_ews_item_get_subject (item);
-		e_ews_connection_expand_dl (cnc, EWS_PRIORITY_MEDIUM, mb, &members, &includes_last, priv->cancellable, error);
+		e_ews_connection_expand_dl_sync (
+			cnc, EWS_PRIORITY_MEDIUM, mb, &members,
+			&includes_last, priv->cancellable, error);
 		if (*error)
 			goto cleanup;
 
@@ -2224,12 +2235,13 @@ ebews_start_sync (gpointer data)
 		GSList *items_created = NULL, *items_updated = NULL;
 		GSList *items_deleted = NULL;
 
-		e_ews_connection_sync_folder_items	(priv->cnc, EWS_PRIORITY_MEDIUM,
-							 &sync_state, priv->folder_id,
-							 "IdOnly", NULL,
-							 EWS_MAX_FETCH_COUNT, &includes_last_item,
-							 &items_created, &items_updated,
-							 &items_deleted, priv->cancellable, &error);
+		e_ews_connection_sync_folder_items_sync (
+			priv->cnc, EWS_PRIORITY_MEDIUM,
+			&sync_state, priv->folder_id,
+			"IdOnly", NULL,
+			EWS_MAX_FETCH_COUNT, &includes_last_item,
+			&items_created, &items_updated,
+			&items_deleted, priv->cancellable, &error);
 
 		if (error)
 			break;
@@ -2345,7 +2357,8 @@ ebews_start_refreshing (EBookBackendEws *ebews)
 
 	PRIV_LOCK (priv);
 
-	if (priv->is_online && priv->cnc && priv->marked_for_offline)
+	if (e_backend_get_online (E_BACKEND (ebews)) &&
+	    priv->cnc != NULL&& priv->marked_for_offline)
 		fetch_deltas (ebews);
 
 	PRIV_UNLOCK (priv);
@@ -2408,7 +2421,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 	e_data_book_view_ref (book_view);
 	e_data_book_view_notify_progress (book_view, -1, _("Searching..."));
 
-	if (!priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		if (priv->ebsdb && e_book_backend_sqlitedb_get_is_populated (priv->ebsdb, priv->folder_id, NULL)) {
 			fetch_from_offline (ebews, book_view, query, error);
 			return;
@@ -2461,9 +2474,10 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 	 * items during auto-completion. Change it if needed. TODO, Personal Address-book should start using
 	 * find_items rather than resolve_names to support all queries */
 	g_hash_table_insert (priv->ops, book_view, cancellable);
-	e_ews_connection_resolve_names	(priv->cnc, EWS_PRIORITY_MEDIUM, auto_comp_str,
-					 EWS_SEARCH_AD, NULL, TRUE, &mailboxes, &contacts,
-					 &includes_last_item, cancellable, &error);
+	e_ews_connection_resolve_names_sync (
+		priv->cnc, EWS_PRIORITY_MEDIUM, auto_comp_str,
+		EWS_SEARCH_AD, NULL, TRUE, &mailboxes, &contacts,
+		&includes_last_item, cancellable, &error);
 	g_free (auto_comp_str);
 	g_hash_table_remove (priv->ops, book_view);
 	e_ews_folder_free_fid (fid);
@@ -2596,10 +2610,8 @@ e_book_backend_ews_load_source (EBookBackend *backend,
 		}
 	}
 
-	if (priv->is_online) {
-		e_backend_set_online (E_BACKEND (backend), TRUE);
+	if (e_backend_get_online (E_BACKEND (backend)))
 		e_book_backend_notify_auth_required (backend, TRUE, NULL);
-	}
 }
 
 static void
@@ -2630,7 +2642,7 @@ e_book_backend_ews_authenticate_user (EBookBackend *backend,
 	ebews = E_BOOK_BACKEND_EWS (backend);
 	priv = ebews->priv;
 
-	if (!ebews->priv->is_online) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		e_book_backend_notify_opened (backend, EDB_ERROR (SUCCESS));
 		return;
 	}
@@ -2659,7 +2671,9 @@ e_book_backend_ews_authenticate_user (EBookBackend *backend,
 		fid->id = g_strdup ("contacts");
 		fid->is_distinguished_id = TRUE;
 		ids = g_slist_append (ids, fid);
-		e_ews_connection_get_folder (cnc, EWS_PRIORITY_MEDIUM, "Default", NULL, ids, &folders, cancellable, &error);
+		e_ews_connection_get_folder_sync (
+			cnc, EWS_PRIORITY_MEDIUM, "Default",
+			NULL, ids, &folders, cancellable, &error);
 
 		e_ews_folder_free_fid (fid);
 		g_slist_free (ids);
@@ -2688,17 +2702,9 @@ e_book_backend_ews_notify_online_cb (EBookBackend *backend,
                                      GParamSpec *spec)
 {
 	EBookBackendEws *ebews;
-	gboolean is_online;
 
 	ebews = E_BOOK_BACKEND_EWS (backend);
 
-	is_online = e_backend_get_online (E_BACKEND (backend));
-
-	if ((ebews->priv->is_online ? 1 : 0) == (is_online ? 1 : 0))
-		return;
-
-	ebews->priv->is_online = is_online;
-
 	if (e_book_backend_is_opened (backend)) {
 		if (ebews->priv->cancellable) {
 			g_cancellable_cancel (ebews->priv->cancellable);
@@ -2706,7 +2712,7 @@ e_book_backend_ews_notify_online_cb (EBookBackend *backend,
 			ebews->priv->cancellable = NULL;
 		}
 
-		if (!is_online) {
+		if (!e_backend_get_online (E_BACKEND (backend))) {
 			e_book_backend_notify_readonly (backend, TRUE);
 			e_book_backend_notify_online (backend, FALSE);
 			if (ebews->priv->cnc) {
