@@ -32,13 +32,15 @@
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
-#include <e-ews-connection.h>
-#include <e-ews-message.h>
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-time-util.h>
 #include <libsoup/soup-misc.h>
+#include <libedataserver/e-source-list.h>
+
+#include "server/e-ews-connection.h"
+#include "server/e-ews-message.h"
+
 #include "e-cal-backend-ews-utils.h"
-#include "libedataserver/e-source-list.h"
 
 /*
  * Iterate over the icalcomponent properties and collect attendees
@@ -448,8 +450,8 @@ ewscal_set_availability_timezone (ESoapMessage *msg,
 	/* Fetch the timezone offsets for the standard (or only) zone.
 	 * Negate it, because Exchange does it backwards */
 	if (xstd) {
-		prop = icalcomponent_get_first_property(xstd, ICAL_TZOFFSETTO_PROPERTY);
-		std_utcoffs = -icalproperty_get_tzoffsetto(prop)/60;
+		prop = icalcomponent_get_first_property (xstd, ICAL_TZOFFSETTO_PROPERTY);
+		std_utcoffs = -icalproperty_get_tzoffsetto (prop) / 60;
 	} else
 		std_utcoffs = 0;
 
@@ -471,7 +473,7 @@ ewscal_set_availability_timezone (ESoapMessage *msg,
 		e_soap_message_start_element(msg, "DaylightTime", NULL, NULL);
 		ewscal_add_availability_timechange (msg, xdaylight, std_utcoffs);
 		e_soap_message_end_element(msg); /* "DaylightTime" */
-	} else 
+	} else
 		/* Set default values*/
 		ewscal_add_availability_default_timechange (msg);
 
