@@ -21,12 +21,14 @@
 #ifndef E_CAL_BACKEND_EWS_UTILS_H
 #define E_CAL_BACKEND_EWS_UTILS_H
 
-#include <e-ews-connection.h>
 #include <libecal/e-cal-component.h>
-#include <e-cal-backend-ews.h>
 #include <libical/icaltime.h>
 #include <libical/icaltimezone.h>
 
+#include "server/e-ews-connection.h"
+
+#include "e-cal-backend-ews.h"
+
 G_BEGIN_DECLS
 #define MINUTES_IN_HOUR 60
 #define SECS_IN_MINUTE 60
@@ -34,7 +36,7 @@ G_BEGIN_DECLS
 const gchar *e_ews_collect_organizer (icalcomponent *comp);
 void e_ews_collect_attendees (icalcomponent *comp, GSList **required, GSList **optional, GSList **resource);
 
-void ewscal_set_time (ESoapMessage *msg, const gchar *name, icaltimetype *t, gboolean with_timezone);
+void ewscal_set_time (ESoapMessage *msg, const gchar *name, icaltimetype *t);
 void ewscal_set_timezone (ESoapMessage *msg, const gchar *name, icaltimezone *icaltz);
 void ewscal_set_availability_timezone (ESoapMessage *msg, icaltimezone *icaltz);
 void ewscal_set_reccurence (ESoapMessage *msg, icalproperty *rrule, icaltimetype *dtstart);
