@@ -44,17 +44,19 @@ which needs to be better organized via functions */
 #include <libedataserver/e-flag.h>
 #include <libical/icalcomponent.h>
 #include <libical/icalparser.h>
-#include <e-ews-connection.h>
-#include <e-ews-item-change.h>
-#include <e-ews-message.h>
+
+#include "server/e-ews-connection.h"
+#include "server/e-ews-item-change.h"
+#include "server/e-ews-message.h"
+
+#include "utils/ews-camel-common.h"
+#include "utils/camel-ews-settings.h"
 
 #include "camel-ews-folder.h"
 #include "camel-ews-private.h"
-#include "camel-ews-settings.h"
 #include "camel-ews-store.h"
 #include "camel-ews-summary.h"
 #include "camel-ews-utils.h"
-#include <ews-camel-common.h>
 
 #define EWS_MAX_FETCH_COUNT 100
 
@@ -438,12 +440,13 @@ camel_ews_folder_get_message (CamelFolder *folder,
 		goto exit;
 	}
 
-	res = e_ews_connection_get_items (cnc, pri, ids, "IdOnly", "item:MimeContent",
-					  TRUE, mime_dir,
-					  &items,
-					  (ESoapProgressFn) camel_operation_progress,
-					  (gpointer) cancellable,
-					  cancellable, error);
+	res = e_ews_connection_get_items_sync (
+		cnc, pri, ids, "IdOnly", "item:MimeContent",
+		TRUE, mime_dir,
+		&items,
+		(ESoapProgressFn) camel_operation_progress,
+		(gpointer) cancellable,
+		cancellable, error);
 	g_free (mime_dir);
 
 	if (!res)
@@ -466,12 +469,14 @@ camel_ews_folder_get_message (CamelFolder *folder,
 		gboolean is_calendar_UID = TRUE;
 
 		// Get AssociatedCalendarItemId with second get_items call
-		res = e_ews_connection_get_items (cnc, pri, ids, "IdOnly", "meeting:AssociatedCalendarItemId",
-						  FALSE, NULL,
-						  &items_req,
-						  (ESoapProgressFn) camel_operation_progress,
-						  (gpointer) cancellable,
-						  cancellable, error);
+		res = e_ews_connection_get_items_sync (
+			cnc, pri, ids, "IdOnly",
+			"meeting:AssociatedCalendarItemId",
+			FALSE, NULL,
+			&items_req,
+			(ESoapProgressFn) camel_operation_progress,
+			(gpointer) cancellable,
+			cancellable, error);
 		if (!res || (items_req && e_ews_item_get_item_type (items_req->data) == E_EWS_ITEM_TYPE_ERROR)) {
 			if (items_req) {
 				g_object_unref (items_req->data);
@@ -564,7 +569,7 @@ ews_folder_get_message_sync (CamelFolder *folder,
 static GPtrArray *
 ews_folder_search_by_expression (CamelFolder *folder,
                                  const gchar *expression,
-				 GCancellable *cancellable,
+                                 GCancellable *cancellable,
                                  GError **error)
 {
 	CamelEwsFolder *ews_folder;
@@ -587,7 +592,7 @@ ews_folder_search_by_expression (CamelFolder *folder,
 static guint32
 ews_folder_count_by_expression (CamelFolder *folder,
                                 const gchar *expression,
-				GCancellable *cancellable,
+                                GCancellable *cancellable,
                                 GError **error)
 {
 	CamelEwsFolder *ews_folder;
@@ -611,7 +616,7 @@ static GPtrArray *
 ews_folder_search_by_uids (CamelFolder *folder,
                            const gchar *expression,
                            GPtrArray *uids,
-			   GCancellable *cancellable,
+                           GCancellable *cancellable,
                            GError **error)
 {
 	CamelEwsFolder *ews_folder;
@@ -781,11 +786,12 @@ ews_sync_mi_flags (CamelFolder *folder,
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 	cnc = camel_ews_store_get_connection (ews_store);
 
-	return e_ews_connection_update_items (cnc, EWS_PRIORITY_LOW,
-					      "AlwaysOverwrite", "SaveOnly",
-					      NULL, NULL,
-					      msg_update_flags, mi_list, NULL,
-					      cancellable, error);
+	return e_ews_connection_update_items_sync (
+		cnc, EWS_PRIORITY_LOW,
+		"AlwaysOverwrite", "SaveOnly",
+		NULL, NULL,
+		msg_update_flags, mi_list, NULL,
+		cancellable, error);
 }
 
 static gboolean
@@ -1021,8 +1027,8 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 	g_slist_free (updated_items);
 
 	if (msg_ids)
-		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+		e_ews_connection_get_items_sync (
+			g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
 			 msg_ids, "IdOnly", SUMMARY_MESSAGE_FLAGS,
 			 FALSE, NULL, &items, NULL, NULL,
 			 cancellable, error);
@@ -1033,11 +1039,11 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 		goto exit;
 
 	if (generic_item_ids)
-		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
-			 generic_item_ids, "IdOnly", SUMMARY_ITEM_FLAGS,
-			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			generic_item_ids, "IdOnly", SUMMARY_ITEM_FLAGS,
+			FALSE, NULL, &items, NULL, NULL,
+			cancellable, error);
 	camel_ews_utils_sync_updated_items (ews_folder, items);
 
 exit:
@@ -1092,11 +1098,11 @@ sync_created_items (CamelEwsFolder *ews_folder,
 	g_slist_free (created_items);
 
 	if (msg_ids)
-		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
-			 msg_ids, "IdOnly", SUMMARY_MESSAGE_PROPS,
-			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			msg_ids, "IdOnly", SUMMARY_MESSAGE_PROPS,
+			FALSE, NULL, &items, NULL, NULL,
+			cancellable, error);
 
 	if (*error)
 		goto exit;
@@ -1105,11 +1111,11 @@ sync_created_items (CamelEwsFolder *ews_folder,
 	items = NULL;
 
 	if (post_item_ids)
-		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
-			 post_item_ids, "IdOnly", SUMMARY_POSTITEM_PROPS,
-			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			post_item_ids, "IdOnly", SUMMARY_POSTITEM_PROPS,
+			FALSE, NULL, &items, NULL, NULL,
+			cancellable, error);
 
 	if (*error)
 		goto exit;
@@ -1118,11 +1124,11 @@ sync_created_items (CamelEwsFolder *ews_folder,
 	items = NULL;
 
 	if (generic_item_ids)
-		e_ews_connection_get_items
-			(g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
-			 generic_item_ids, "IdOnly", SUMMARY_ITEM_PROPS,
-			 FALSE, NULL, &items, NULL, NULL,
-			 cancellable, error);
+		e_ews_connection_get_items_sync (
+			g_object_ref (cnc), EWS_PRIORITY_MEDIUM,
+			generic_item_ids, "IdOnly", SUMMARY_ITEM_PROPS,
+			FALSE, NULL, &items, NULL, NULL,
+			cancellable, error);
 
 	camel_ews_utils_sync_created_items (ews_folder, items);
 
@@ -1195,13 +1201,13 @@ ews_refresh_info_sync (CamelFolder *folder,
 		GSList *items_deleted = NULL;
 		guint32 total, unread;
 
-		e_ews_connection_sync_folder_items
-							(cnc, EWS_PRIORITY_MEDIUM,
-							 &sync_state, id,
-							 "IdOnly", NULL,
-							 EWS_MAX_FETCH_COUNT, &includes_last_item,
-							 &items_created, &items_updated,
-							 &items_deleted, cancellable, &rerror);
+		e_ews_connection_sync_folder_items_sync (
+			cnc, EWS_PRIORITY_MEDIUM,
+			&sync_state, id,
+			"IdOnly", NULL,
+			EWS_MAX_FETCH_COUNT, &includes_last_item,
+			&items_created, &items_updated,
+			&items_deleted, cancellable, &rerror);
 
 		if (rerror)
 			break;
@@ -1347,10 +1353,11 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 		ids = g_slist_append (ids, (gchar *) uids->pdata[i]);
 	}
 
-	if (e_ews_connection_move_items	(cnc, EWS_PRIORITY_MEDIUM,
-					 dst_id, !delete_originals,
-					 ids, &ret_items,
-					 cancellable, &rerror)) {
+	if (e_ews_connection_move_items_sync (
+			cnc, EWS_PRIORITY_MEDIUM,
+			dst_id, !delete_originals,
+			ids, &ret_items,
+			cancellable, &rerror)) {
 		if (delete_originals) {
 			changes = camel_folder_change_info_new ();
 			for (i = 0; i < uids->len; i++) {
@@ -1406,10 +1413,9 @@ ews_delete_messages (CamelFolder *folder,
 
 		delete_type = expunge ? EWS_HARD_DELETE : EWS_MOVE_TO_DELETED_ITEMS;
 
-		camel_service_lock (CAMEL_SERVICE (ews_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-		status = e_ews_connection_delete_items (cnc, EWS_PRIORITY_MEDIUM, deleted_items, delete_type,
-							EWS_SEND_TO_NONE, FALSE, cancellable, &rerror);
-		camel_service_unlock (CAMEL_SERVICE (ews_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+		status = e_ews_connection_delete_items_sync (
+			cnc, EWS_PRIORITY_MEDIUM, deleted_items, delete_type,
+			EWS_SEND_TO_NONE, FALSE, cancellable, &rerror);
 
 		if (!status && rerror->code == EWS_CONNECTION_ERROR_ITEMNOTFOUND) {
 			/* If delete failed due to the item not found, ignore the error,
@@ -1594,7 +1600,7 @@ camel_ews_folder_init (CamelEwsFolder *ews_folder)
 		CAMEL_MESSAGE_DRAFT | CAMEL_MESSAGE_FLAGGED | CAMEL_MESSAGE_SEEN |
 		CAMEL_MESSAGE_FORWARDED | CAMEL_MESSAGE_USER;
 
-	folder->folder_flags = CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY | CAMEL_FOLDER_HAS_SEARCH_CAPABILITY;
+	folder->folder_flags = CAMEL_FOLDER_HAS_SUMMARY_CAPABILITY;
 
 	ews_folder->priv->search_lock = g_mutex_new ();
 	ews_folder->priv->state_lock = g_mutex_new ();
