@@ -37,15 +37,17 @@
 #include <glib/gstdio.h>
 
 #include <libedataserver/e-flag.h>
-#include <e-ews-item-change.h>
-#include <e-ews-message.h>
+
+#include "server/e-ews-item-change.h"
+#include "server/e-ews-message.h"
+
+#include "utils/camel-ews-settings.h"
+#include "utils/ews-esource-utils.h"
 
 #include "camel-ews-folder.h"
-#include "camel-ews-settings.h"
 #include "camel-ews-store.h"
 #include "camel-ews-summary.h"
 #include "camel-ews-utils.h"
-#include "ews-esource-utils.h"
 
 #ifdef G_OS_WIN32
 #include <winsock2.h>
@@ -286,20 +288,15 @@ ews_connect_sync (CamelService *service,
 	if (camel_service_get_connection_status (service) == CAMEL_SERVICE_DISCONNECTED)
 		return FALSE;
 
-	camel_service_lock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-
-	if (priv->cnc) {
-		camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+	if (priv->cnc)
 		return TRUE;
-	}
 
 	priv->cnc = e_ews_connection_new (hosturl, user, NULL,
 					  G_CALLBACK (ews_store_authenticate), service,
 					  error);
 
 	if (!priv->cnc) {
-		camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-		camel_service_disconnect_sync (service, TRUE, NULL);
+		camel_service_disconnect_sync (service, TRUE, cancellable, NULL);
 		return FALSE;
 	}
 
@@ -311,16 +308,13 @@ ews_connect_sync (CamelService *service,
 	if (!success) {
 		g_object_unref (priv->cnc);
 		priv->cnc = NULL;
-		camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-		camel_service_disconnect_sync (service, TRUE, NULL);
+		camel_service_disconnect_sync (service, TRUE, cancellable, NULL);
 		return FALSE;
 	}
 
 	camel_offline_store_set_online_sync (
 		CAMEL_OFFLINE_STORE (ews_store), TRUE, cancellable, NULL);
 
-	camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-
 	return TRUE;
 }
 
@@ -337,16 +331,12 @@ ews_disconnect_sync (CamelService *service,
 	if (!service_class->disconnect_sync (service, clean, cancellable, error))
 		return FALSE;
 
-	camel_service_lock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-
 	/* TODO cancel all operations in the connection */
 	if (ews_store->priv->cnc) {
 		g_object_unref (ews_store->priv->cnc);
 		ews_store->priv->cnc = NULL;
 	}
 
-	camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
-
 	return TRUE;
 }
 
@@ -427,7 +417,7 @@ ews_authenticate_sync (CamelService *service,
 	if (!sync_state)
 		initial_setup = TRUE;
 
-	e_ews_connection_sync_folder_hierarchy (
+	e_ews_connection_sync_folder_hierarchy_sync (
 		priv->cnc, EWS_PRIORITY_MEDIUM,
 		&sync_state, &includes_last_folder,
 		&folders_created, &folders_updated, &folders_deleted,
@@ -459,9 +449,10 @@ ews_authenticate_sync (CamelService *service,
 		}
 
 		/* fetch system folders first using getfolder operation*/
-		e_ews_connection_get_folder (ews_store->priv->cnc, EWS_PRIORITY_MEDIUM, "IdOnly",
-						     NULL, folder_ids, &folders,
-						     cancellable, &folder_err);
+		e_ews_connection_get_folder_sync (
+			ews_store->priv->cnc, EWS_PRIORITY_MEDIUM, "IdOnly",
+			NULL, folder_ids, &folders,
+			cancellable, &folder_err);
 
 		if (g_slist_length (folders) && (g_slist_length (folders) != G_N_ELEMENTS (system_folder)))
 			d(printf("Error : not all folders are returned by getfolder operation"));
@@ -652,14 +643,15 @@ ews_refresh_finfo (CamelEwsStore *ews_store)
 	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (ews_store)))
 		return FALSE;
 
-	if (!camel_service_connect_sync ((CamelService *) ews_store, NULL))
+	if (!camel_service_connect_sync ((CamelService *) ews_store, NULL, NULL))
 		return FALSE;
 
 	sync_state = camel_ews_store_summary_get_string_val (ews_store->summary, "sync_state", NULL);
 
-	e_ews_connection_sync_folder_hierarchy_start	(ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-							 sync_state, ews_folder_hierarchy_ready_cb,
-							 NULL, g_object_ref (ews_store));
+	e_ews_connection_sync_folder_hierarchy (
+		ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
+		sync_state, NULL, ews_folder_hierarchy_ready_cb,
+		g_object_ref (ews_store));
 	g_free (sync_state);
 	return TRUE;
 }
@@ -685,7 +677,7 @@ ews_get_folder_info_sync (CamelStore *store,
 
 	g_mutex_lock (priv->get_finfo_lock);
 	if (!(camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store))
-	      && camel_service_connect_sync ((CamelService *) store, error))) {
+	      && camel_service_connect_sync ((CamelService *) store, cancellable, error))) {
 		g_mutex_unlock (priv->get_finfo_lock);
 		goto offline;
 	}
@@ -705,10 +697,11 @@ ews_get_folder_info_sync (CamelStore *store,
 		goto offline;
 	}
 
-	if (!e_ews_connection_sync_folder_hierarchy (ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-						    &sync_state, &includes_last_folder,
-						    &folders_created, &folders_updated,
-						    &folders_deleted, cancellable, error)) {
+	if (!e_ews_connection_sync_folder_hierarchy_sync (
+			ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
+			&sync_state, &includes_last_folder,
+			&folders_created, &folders_updated,
+			&folders_deleted, cancellable, error)) {
 		if (error)
 			g_warning ("Unable to fetch the folder hierarchy: %s :%d \n",
 				   (*error)->message, (*error)->code);
@@ -760,10 +753,11 @@ ews_create_folder_sync (CamelStore *store,
 	}
 
 	/* Make the call */
-	if (!e_ews_connection_create_folder (ews_store->priv->cnc,
-					     EWS_PRIORITY_MEDIUM, fid,
-					     FALSE, folder_name, &folder_id,
-					     cancellable, error)) {
+	if (!e_ews_connection_create_folder_sync (
+			ews_store->priv->cnc,
+			EWS_PRIORITY_MEDIUM, fid,
+			FALSE, folder_name, &folder_id,
+			cancellable, error)) {
 		g_free (fid);
 		return NULL;
 	}
@@ -815,10 +809,11 @@ ews_delete_folder_sync (CamelStore *store,
 		return FALSE;
 	}
 
-	if (!e_ews_connection_delete_folder (ews_store->priv->cnc,
-					     EWS_PRIORITY_MEDIUM,
-					     fid, FALSE, "HardDelete",
-					     cancellable, error)) {
+	if (!e_ews_connection_delete_folder_sync (
+			ews_store->priv->cnc,
+			EWS_PRIORITY_MEDIUM,
+			fid, FALSE, "HardDelete",
+			cancellable, error)) {
 		g_free (fid);
 		return FALSE;
 	}
@@ -946,8 +941,9 @@ ews_rename_folder_sync (CamelStore *store,
 		rename_data->folder_id = fid;
 		rename_data->change_key = changekey;
 
-		if (!e_ews_connection_update_folder (ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-						     rename_folder_cb, rename_data, cancellable, error)) {
+		if (!e_ews_connection_update_folder_sync (
+				ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
+				rename_folder_cb, rename_data, cancellable, error)) {
 			g_free (rename_data);
 			goto out;
 		}
@@ -972,8 +968,9 @@ ews_rename_folder_sync (CamelStore *store,
 				goto out;
 			}
 		}
-		if (!e_ews_connection_move_folder (ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-						   pfid, fid, cancellable, error)) {
+		if (!e_ews_connection_move_folder_sync (
+				ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
+				pfid, fid, cancellable, error)) {
 			g_free (pfid);
 			goto out;
 		}
@@ -1069,7 +1066,7 @@ camel_ews_store_connected (CamelEwsStore *ews_store,
 		return FALSE;
 	}
 
-	if (!camel_service_connect_sync ((CamelService *) ews_store, error))
+	if (!camel_service_connect_sync ((CamelService *) ews_store, NULL, error))
 		return FALSE;
 
 	return TRUE;
