@@ -30,11 +30,12 @@
 
 #include <glib/gi18n-lib.h>
 
-#include "camel-ews-settings.h"
+#include "utils/camel-ews-settings.h"
+#include "utils/ews-camel-common.h"
+
 #include "camel-ews-store.h"
 #include "camel-ews-transport.h"
 #include "camel-ews-utils.h"
-#include <ews-camel-common.h>
 
 #define REPLY_VIEW "default message attachments threading"
 
