@@ -21,7 +21,9 @@
 #define CAMEL_EWS_UTILS_H
 
 #include <camel/camel.h>
-#include <e-ews-connection.h>
+
+#include "server/e-ews-connection.h"
+
 #include "camel-ews-store.h"
 #include "camel-ews-folder.h"
 
@@ -86,7 +88,6 @@ CamelFolderInfo *
 void	camel_ews_utils_sync_deleted_items	(CamelEwsFolder *ews_folder,
 						 GSList *items_deleted);
 void	camel_ews_utils_sync_created_items	(CamelEwsFolder *ews_folder,
-						 EEwsConnection *cnc,
 						 GSList *items_created);
 void	camel_ews_utils_sync_updated_items	(CamelEwsFolder *ews_folder,
 						 GSList *items_updated);
