@@ -26,10 +26,12 @@
 #include <ctype.h>
 #include <glib.h>
 #include <glib/gprintf.h>
+
+#include "server/e-ews-connection.h"
+#include "server/e-ews-folder.h"
+#include "server/e-ews-message.h"
+
 #include "utils.h"
-#include <e-ews-connection.h>
-#include <e-ews-folder.h>
-#include <e-ews-message.h>
 
 void createfolder_tests_run ();
 
@@ -83,12 +85,12 @@ op_test_create_folder ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, TRUE, NULL, NULL, NULL);
+	cnc = e_ews_connection_new (uri, username, password, NULL, NULL, NULL);
 	g_assert (cnc != NULL);
-	e_ews_connection_create_folder_start	(cnc, EWS_PRIORITY_MEDIUM, "inbox",
-						 TRUE ,"test",
-						 create_folder_cb,
-						 cancellable, NULL);
+	e_ews_connection_create_folder (
+		cnc, EWS_PRIORITY_MEDIUM, "inbox",
+		TRUE ,"test", cancellable,
+		create_folder_cb, NULL);
 
 }
 
