@@ -26,10 +26,12 @@
 #include <ctype.h>
 #include <glib.h>
 #include <glib/gprintf.h>
+
+#include "server/e-ews-connection.h"
+#include "server/e-ews-item.h"
+#include "server/e-ews-message.h"
+
 #include "utils.h"
-#include <e-ews-connection.h>
-#include <e-ews-item.h>
-#include <e-ews-message.h>
 
 static void op_test_create_item ();
 void cuditem_tests_run ();
@@ -106,17 +108,17 @@ op_test_create_item ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, TRUE, NULL, NULL, NULL);
+	cnc = e_ews_connection_new (uri, username, password, NULL, NULL, NULL);
 	g_assert (cnc != NULL);
 
 	//to check how to change to real data
 	folderid = "AQASAG1hbmR5Lnd1QGludGVsLmNvbQAuAAADnUl3sZrICU6Xd1qXV+rpVwEAJvRPgQpR30KhJ7wqBr4YXgAAAY6W+gAAAA==";
 
-	e_ews_connection_create_items_start	(cnc, EWS_PRIORITY_MEDIUM,
-						 NULL, "SendToAllAndSaveCopy", folderid,
-						 op_test_create_item_get_soap_msg, NULL,
-						 create_item_ready_callback,
-						 cancellable, NULL);
+	e_ews_connection_create_items (
+		cnc, EWS_PRIORITY_MEDIUM,
+		NULL, "SendToAllAndSaveCopy", folderid,
+		op_test_create_item_get_soap_msg, NULL,
+		cancellable, create_item_ready_callback, NULL);
 }
 
 static gboolean
