@@ -28,9 +28,10 @@
 #include <libedata-cal/e-cal-backend-sexp.h>
 #include "libedataserver/e-sexp.h"
 #include "e-ews-query-to-restriction.h"
-#include "e-ews-message.h"
 #include <camel/camel.h>
 
+#include "server/e-ews-message.h"
+
 #define d(x) x
 
 #define WRITE_CONTAINS_MESSAGE(msg, mode, compare, uri, val) \
@@ -296,7 +297,7 @@ e_ews_implement_contact_contains (ESExp *f,
 
 				WRITE_CONTAINS_MESSAGE (msg, mode, "IgnoreCase", "item:Categories", value);
 			}
-			
+
 			g_free (mode);
 		}
 	}
@@ -791,7 +792,7 @@ func_eq (ESExp *f,
 
 	if (argv[0]->type == ESEXP_RES_STRING) {
 		const gchar *name;
-	       	gchar *field_uri = NULL;
+		gchar *field_uri = NULL;
 
 		name = argv[0]->value.string;
 
